#
# FIX.R - Round toward zero.
#


##-----------------------------------------------------------------------------
fix <- function(A)
    trunc(A)

